@@ -41,6 +41,10 @@ For to encode unicode strings to other codecs the functions :func:`force_encodin
 
 The :func:`round_traditional` function get provided by this module for traditional rounding of float values. The
 function signature is fully compatible to Python's :func:`round` function.
+
+The function :func:`instantiate_config_parser` ensures that the :class:`~configparser.ConfigParser` instance
+is correctly configured, e.g. to support case-sensitive config variable names and to use
+:class:`ExtendedInterpolation` for the interpolation argument.
 """
 import datetime
 import getpass
@@ -51,12 +55,16 @@ import socket
 import sys
 import unicodedata
 
+from configparser import ConfigParser, ExtendedInterpolation
 from typing import Any, AnyStr, Dict, Iterable, Optional, cast
 
 
-__version__ = '0.1.13'
+__version__ = '0.1.15'
 
 
+CFG_EXT: str = ".cfg"                           #: CFG config file extension
+INI_EXT: str = ".ini"                           #: INI config file extension
+
 DATE_ISO: str = '%Y-%m-%d'                      #: ISO string format for date values (e.g. in config files/variables)
 DATE_TIME_ISO: str = '%Y-%m-%d %H:%M:%S.%f'     #: ISO string format for datetime values
 
@@ -158,6 +166,18 @@ def force_encoding(text: AnyStr, encoding: str = DEF_ENCODING, errors: str = DEF
     return enc_str.decode(encoding=encoding)
 
 
+def instantiate_config_parser() -> ConfigParser:
+    """ instantiate and prepare config file parser. """
+    cfg_parser = ConfigParser(interpolation=ExtendedInterpolation())
+    # set optionxform to have case sensitive var names (or use 'lambda option: option')
+    # mypy V 0.740 bug - see mypy issue #5062: adding pragma "type: ignore" breaks PyCharm (showing
+    # .. inspection warning "Non-self attribute could not be type-hinted"), but
+    # .. also cast(Callable[[Arg(str, 'option')], str], str) and # type: ... is not working
+    # .. (because Arg is not available in plain mypy, only in the extra mypy_extensions package)
+    setattr(cfg_parser, 'optionxform', str)
+    return cfg_parser
+
+
 def norm_line_sep(text: str) -> str:
     """ convert any combination of line separators in the passed :paramref:`~norm_line_sep.text` to new-line characters.
 
